Inputs to the event collector that come from the synthetic-user
pool (see px-camoufox/src/infrastructure/synthetic_user.rs).
Kept as a standalone struct so px-native doesn’t depend on the
camoufox crate.
Inputs to the event collector that come from the synthetic-user
pool (see px-camoufox/src/infrastructure/synthetic_user.rs).
Kept as a standalone struct so px-native doesn’t depend on the
camoufox crate.