pub struct XorKeys {
pub payload: u8,
pub secret_feed: u8,
}Expand description
XOR keys for the two cipher passes the eT15wiaE family of tenants uses. Other tenants can override either or both at load time.
Fields
payload: u8Payload-cipher byte XOR key (JS iS). Default 50.
secret_feed: u8Secret-feed byte XOR key (JS vJ). Default 10.